{% extends "base.html" %}

{% load i18n %}

{% block head_title %}{% trans "Account Inactive" %}{% endblock %}

{% block content %}
<h1>{% trans "Account Inactive" %}</h1>

<p>{% trans "This account is inactive." %}</p>
{% endblock %}
