{% load i18n %}
<div class="mt-4 px-4 sm:px-6 lg:px-8">
  <div class="sm:flex sm:items-center">
    <div class="sm:flex-auto text-center ">
      <h1 class="text-base font-semibold leading-6 text-gray-900">Users</h1>
      <p class="mt-2 text-sm text-gray-700">A list of all the users you can try.</p>
    </div>
  </div>
  <div class="mt-8 flow-root">
    <div class="-mx-4 -my-2 overflow-x-auto sm:-mx-6 lg:-mx-8">
      <div class="inline-block min-w-full py-2 align-middle sm:px-6 lg:px-8">
        <div class="overflow-hidden shadow ring-1 ring-black ring-opacity-5 sm:rounded-lg">
          <table class="min-w-full divide-y divide-gray-300">
            <thead class="bg-gray-50">
              <tr>
                <th scope="col" class="py-3.5 pl-4 pr-3 text-left text-sm font-semibold text-gray-900 sm:pl-6">{% trans "User Name" %}</th>
                <th scope="col" class="px-3 py-3.5 text-left text-sm font-semibold text-gray-900">{% trans "Password" %}</th>
                </th>
                <th scope="col" class="px-3 py-3.5 text-left text-sm font-semibold text-gray-900">{% trans "Type" %}</th>
                </th>
              </tr>
            </thead>
            <tbody class="divide-y divide-gray-200 bg-white">
               <tr>
                <td class="whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-6">{% trans "user1" %}</td>
                <td class="whitespace-nowrap px-3 py-4 text-sm text-gray-500">{% trans "user1" %}</td>
                <td class="whitespace-nowrap px-3 py-4 text-sm text-gray-500">{% trans "Superuser" %}</td>
              </tr>

              </tr>
              <tr>
                <td class="whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-6">{% trans "user2" %}</td>
                <td class="whitespace-nowrap px-3 py-4 text-sm text-gray-500">{% trans "user2" %}</td>
                <td class="whitespace-nowrap px-3 py-4 text-sm text-gray-500">{% trans "Admin" %}</td>
              </tr>
              <tr>
                <td class="whitespace-nowrap py-4 pl-4 pr-3 text-sm font-medium text-gray-900 sm:pl-6">{% trans "user3" %}</td>
                <td class="whitespace-nowrap px-3 py-4 text-sm text-gray-500">{% trans "user3" %}</td>
                <td class="whitespace-nowrap px-3 py-4 text-sm text-gray-500">{% trans "User" %}</td>
              </tr>
            </tbody>
          </table>
        </div>
      </div>
    </div>
  </div>
</div>
