# Generated by Django 5.2.7 on 2025-11-19 06:29

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("tag_me", "0002_systemtag_search_tags_usertag_search_tags_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="systemtag",
            name="comment",
            field=models.CharField(
                blank=True, max_length=255, null=True, verbose_name="Comment"
            ),
        ),
        migrations.AddField(
            model_name="systemtag",
            name="field_name",
            field=models.CharField(
                blank=True,
                editable=False,
                max_length=255,
                null=True,
                verbose_name="Field name",
            ),
        ),
        migrations.AddField(
            model_name="systemtag",
            name="field_verbose_name",
            field=models.CharField(
                blank=True,
                default=None,
                editable=False,
                max_length=255,
                null=True,
                verbose_name="Field verbose",
            ),
        ),
        migrations.AddField(
            model_name="systemtag",
            name="meta",
            field=models.JSONField(
                blank=True,
                default=dict,
                max_length=255,
                null=True,
                verbose_name="Field meta data",
            ),
        ),
        migrations.AddField(
            model_name="systemtag",
            name="model_name",
            field=models.CharField(
                blank=True,
                default=None,
                editable=False,
                max_length=255,
                null=True,
                verbose_name="Model name",
            ),
        ),
        migrations.AddField(
            model_name="systemtag",
            name="model_verbose_name",
            field=models.CharField(
                blank=True,
                default=None,
                editable=False,
                max_length=255,
                null=True,
                verbose_name="Model verbose",
            ),
        ),
        migrations.AddField(
            model_name="systemtag",
            name="tagged_field",
            field=models.ForeignKey(
                blank=True,
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="system_tags",
                to="tag_me.taggedfieldmodel",
                verbose_name="Tagged Field",
            ),
        ),
        migrations.AddField(
            model_name="systemtag",
            name="ui_display_name",
            field=models.CharField(
                blank=True,
                help_text="Display name for the tag in UI",
                max_length=50,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="usertag",
            name="tagged_field",
            field=models.ForeignKey(
                blank=True,
                editable=False,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="user_tags",
                to="tag_me.taggedfieldmodel",
                verbose_name="Tagged Field",
            ),
        ),
    ]
